#!/bin/bash

# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0


#deleting all folders of microk8s
sudo snap remove microk8s
echo -e "\e[1;32mmicrok8s completely uninstalled\e[0m"

