#!/bin/bash
#Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0
#sudo apt-get update
#sudo apt-get install expect -y
#export HOST_IP=$(hostname -I | cut -d' ' -f1)
#echo "Installing edgesoftware ..."
#pip3 install --upgrade pip --user && pip3 install edgesoftware --user
#echo $HOST_IP
#/usr/bin/expect -c '
#set timeout -1
#spawn $::env(HOME)/.local/bin/edgesoftware install intelligent-connection-management-for-automated-handover 6241499a9654a8f4bd360ec5
#expect "Please enter the Product Key. The Product Key is contained in the email you received from Intel confirming your download:" {send "54459efe-476d-4574-b1e2-aadb9482a78a\n"}
#expect eof'

echo "Work in Progress"
