#!/bin/bash

# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0

sudo docker rmi -f openvino/model_server:latest
echo -e "\e[1;32mModel-server uninstalled successfully\e[0m" 
