#!/bin/bash

# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0


sudo docker rmi openvino/workbench:2021.4.2
echo -e "\e[1;32mWorkbench images uninstalled successfully\e[0m"

