#!/bin/bash


# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0

docker pull openvino/onnxruntime_ep_ubuntu18
echo -e "\e[1;32mThe onnx is image is pulled\e[0m"
echo -e "\e[1;36mTo view the images : docker images\e[0m"
