#!/bin/bash


# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0


docker pull intel/intel-optimized-tensorflow
echo -e "\e[1;32mImage is pulled successfully\e[0m"
echo -e "\e[1;36mTo view the images--> docker images\e[0m"

